@@ -21,6 +21,7 @@ from sensiml.datamanager import (
     PipelineSeeds,
     Projects,
     SegmenterSet,
+    Team,
 )
 from sensiml.datamanager.knowledgepack import (
     get_knowledgepack,
@@ -76,6 +77,13 @@ def print_list(func):
             ]
             additional_keys = ["Cached"]
 
+        if func.__name__ == "list_sandboxes":
+            extra = [
+                {"CPU Used (seconds)": item.last_cpu_clock_time}
+                for name, item in result.items()
+            ]
+            additional_keys = ["CPU Used (seconds)"]
+
         for index, value in enumerate(extra):
             tmp_dict[index].update(value)
 
@@ -88,7 +96,7 @@ def print_list(func):
 
 
 class SensiML(object):
-    """Entrance to SensiML Analytic Suite"""
+    """Entrance to SensiML Analytics Toolkit"""
 
     # Server Minimum Version For Campatibility
     __minversion__ = "2019.1.0"
@@ -116,6 +124,7 @@ class SensiML(object):
         self.platforms = PlatformDescriptions(self._connection)
         self.platforms_v2 = ClientPlatformDescriptions(self._connection)
         self.seeds = PipelineSeeds(self._connection)
+        self.team = Team(self._connection)
         self.snippets = Snippets(
             self.list_functions(kp_functions=False, qgrid=False),
             self.functions.function_list,
@@ -147,13 +156,12 @@ class SensiML(object):
 
         if response_data["SensiML_Python_Library_Windows"] != self.__minversion__:
             print(
-                "SensiML Python Client Library is out of date. Update before connecting to the server."
+                "The SensiML Python SDK is out of date. Update before connecting to the server."
             )
-            print("In order to update sensiml client use 'pip install sensiml -U'.")
             print(
-                "For Instrunctions on updating SensiML Client for the Analytic Studio visit https://sensiml.atlassian.net/wiki/spaces/SS/pages/115179614/Updating+SensiML+Client"
+                "In order to update the SensiML Python SDK use 'pip install sensiml -U'"
             )
-            raise Exception("Python Client is out of date.")
+            raise Exception("SensiML Python SDK is out of date.")
 
     def logout(self, name=None):
         """Logs out of the current connection."""
@@ -185,7 +193,7 @@ class SensiML(object):
         Args:
             functype (str, None): Return only functions with the specified type. ie. "Segmenter"
             subtype (str, None): Return only functions with the specified subtype. ie. "Sensor"
-            kp_functions (boolean, True): Return only functions that run on tbe loaded to a device.
+            kp_functions (boolean, True): Return only functions that run on the loaded device.
             Excludes functions such as feature selection and model training.
         """
 
@@ -202,6 +210,7 @@ class SensiML(object):
                         "KP FUNCTION": f.has_c_version,
                         "UUID": f.uuid,
                         "LIBRARY": f.library_pack,
+                        "AVAILABLE": f.automl_available,
                     }
                     for name, f in self.functions.function_list.items()
                 ]
@@ -214,6 +223,7 @@ class SensiML(object):
                     "SUBTYPE",
                     "DESCRIPTION",
                     "KP FUNCTION",
+                    "AVAILABLE",
                     "UUID",
                     "LIBRARY",
                 ]
@@ -280,10 +290,10 @@ class SensiML(object):
 
     def get_automl_parameter_inventory(self):
         """
-        inventory paramenters for AutoML
+        inventory parameters for AutoML
 
         Returns:
-            DataFrame: Automl parameter inventory
+            DataFrame: AutoML parameter inventory
         """
 
         url = "automl/inventory/"
@@ -324,7 +334,7 @@ class SensiML(object):
         return self._project
 
     def get_featurefile(self, uuid):
-        """Get a featruefile by uuid
+        """Get a featurefile by uuid
 
         Args:
             get_objects (bool, False): Also return the featurefile objects.
@@ -629,7 +639,7 @@ class SensiML(object):
 
         capture_files = os.listdir(capture_dir)
         for capture in capture_files:
-            print("Uploading Capture data, metadata and lables for {}".format(capture))
+            print("Uploading Capture data, metadata, and labels for {}".format(capture))
             try:
 
                 capture_metadata = {}
