@@ -27,7 +27,7 @@ class CaptureTaskFailedError(Exception):
 
 
 class Capture(object):
-    """Base class for an Capture."""
+    """Base class for a Capture."""
 
     def __init__(
         self,
@@ -41,7 +41,7 @@ class Capture(object):
         created_at=None,
         **kwargs
     ):
-        """Initialize an Capture instance."""
+        """Initialize a Capture instance."""
         self._connection = connection
         self._project = project
         self._filename = filename
@@ -231,7 +231,7 @@ class Capture(object):
         return Capture(**new_dict)
 
     def data(self, cloud=True):
-        """Calls the REST API and retrieves an capture's sensor data.
+        """Calls the REST API and retrieves a capture's sensor data.
 
         Returns:
             data (DataFrame): all sensor data associated with the capture
