@@ -232,7 +232,7 @@ class ClientPlatformDescription(object):
         float_options=None,
         platform_version="",
     ):
-        """Generates a default configuration dictionary for downloading a knowledgepack using this platform progrmatically
+        """Generates a default configuration dictionary for downloading a knowledgepack using this platform programmatically
 
         Args:
             test_data (str): name of test data file to load onto knowledge pack,
