@@ -15,6 +15,7 @@ class Function(object):
     _subtype = ""
     _has_c_version = False
     _library_pack = ""
+    _automl_available = False
 
     def __init__(self, connection):
         self._connection = connection
@@ -83,6 +84,14 @@ class Function(object):
     def library_pack(self, value):
         self._library_pack = value
 
+    @property
+    def automl_available(self):
+        return self._automl_available
+
+    @automl_available.setter
+    def automl_available(self, value):
+        self._automl_available = value
+
     def get_function_info(self):
         """Returns function properties after checking integrity constraints.
 
@@ -114,6 +123,7 @@ class Function(object):
             "subtype": self.subtype,
             "has_c_version": self.has_c_version,
             "library_pack": self.library_pack,
+            "automl_available": self.automl_available,
         }
 
         return function_info
@@ -131,6 +141,7 @@ class Function(object):
             self.input_contract = response_data["input_contract"]
             self.has_c_version = response_data["has_c_version"]
             self.library_pack = response_data["library_pack"]
+            self.automl_available = response_data["automl_available"]
 
         return response_data
 
@@ -160,6 +171,7 @@ class Function(object):
         self.subtype = input_dictionary["subtype"]
         self.has_c_version = input_dictionary["has_c_version"]
         self.library_pack = input_dictionary["library_pack"]
+        self.automl_available = input_dictionary["automl_available"]
 
     def __str__(self):
         input_string = ""
