@@ -67,6 +67,7 @@ class KnowledgePack(VisualizeMixin):
         self._class_map = ""
         self._device_config = DeviceConfig()
         self._feature_file_cache = None
+        self._training_metrics = None
 
     @property
     def uuid(self):
@@ -114,7 +115,7 @@ class KnowledgePack(VisualizeMixin):
     @property
     def training_metrics(self):
         """The training metrics associated with the KnowledgePack"""
-        return self._model_results.get("training_metrics", None)
+        return self.model_parameters.get("training_metrics", None)
 
     @property
     def pipeline_summary(self):
@@ -155,7 +156,7 @@ class KnowledgePack(VisualizeMixin):
 
     @property
     def sensor_summary(self):
-        """A summary of sensor streams usd by the KnowledgePack"""
+        """A summary of sensor streams used by the KnowledgePack"""
         return self._sensor_summary
 
     @property
@@ -214,10 +215,19 @@ class KnowledgePack(VisualizeMixin):
 
     @property
     def cost_report(self):
-        """A print(ed tabular report of the device cost incurred by the KnowledgePack"""
-        print(self.get_report("cost"))
+        """A printed tabular report of the device cost incurred by the KnowledgePack"""
+        return self.get_report("cost")
 
-    def get_report(self, report_type):
+    @property
+    def cost_report_json(self):
+        """A JSON report of the Knowledge Pack cost summary"""
+        return self.get_report("json")
+
+    def cost_resource_summary(self, processor_uuid=None):
+        """A summary of resources and time needed in a classification from a Knowledge Pack"""
+        return self.get_report("resource_summary", processor_uuid)
+
+    def get_report(self, report_type, processor_uuid=None):
         """Sends a request for a report to the server and returns the result.
 
         Args:
@@ -227,13 +237,33 @@ class KnowledgePack(VisualizeMixin):
             (string): string representation of desired report
 
         """
-        url = "project/{0}/knowledgepack/{2}/report/{3}/".format(
-            self._project_uuid, self._sandbox_uuid, self.uuid, report_type
+        url = "project/{0}/knowledgepack/{1}/report/{2}/".format(
+            self._project_uuid, self.uuid, report_type
         )
-        response = self._connection.request(
-            "get", url, headers={"Accept": "text/plain"}
-        )
-        return response.text
+
+        if report_type == "cost":
+            response = self._connection.request(
+                "get", url, headers={"Accept": "text/plain"}
+            )
+            return response.text
+        elif report_type == "json":
+            response = self._connection.request(
+                "get", url, headers={"Accept": "application/json"}
+            )
+            return response.json()
+        elif report_type == "resource_summary":
+            if processor_uuid is None:
+                url = "project/{0}/knowledgepack/{1}/report/{2}/".format(
+                    self._project_uuid, self.uuid, report_type
+                )
+            else:
+                url = "project/{0}/knowledgepack/{1}/report/{2}/{3}".format(
+                    self._project_uuid, self.uuid, report_type, processor_uuid
+                )
+            response = self._connection.request(
+                "get", url, headers={"Accept": "application/json"}
+            )
+            return response.json()
 
     def recognize_features(self, data):
         """Sends a single vector of features to the KnowledgePack for recognition.
@@ -276,10 +306,10 @@ class KnowledgePack(VisualizeMixin):
         """Sends a DataFrame of raw signals to be run through the feature generation pipeline and recognized.
 
         Args:
-            capturefile (str): The name of a captured file uploaded throught the data capture lab
+            capturefile (str): The name of a file uploaded through the data capture lab
             datafile (str): The name of an uploading datafile
             platform (str): "emulator" or "cloud". The "emulator" will run compiled c code giving device exact results,
-                 the cloud runs similary to training providing more flexibility in returning early results by setting the
+                 the cloud runs similarly to training providing more flexibility in returning early results by setting the
                  stop step.
             stop_step (int): for debugging, if you want to stop the pipeline at a particular step, set stop_step
               to its index
@@ -431,7 +461,6 @@ class KnowledgePack(VisualizeMixin):
         response = self._connection.request("get", url)
         data, err = utility.check_server_response(response)
         if err is False:
-            # import pdb; pdb.set_trace()
             response_data = data or {}
             return utility.check_pipeline_status(
                 response_data, self._handle_result, silent=silent
@@ -465,7 +494,7 @@ class KnowledgePack(VisualizeMixin):
                 return response
 
     def save(self, name):
-        """Save a knowledpack with a name.
+        """Save a knowledgepack with a name.
 
         Returns:
             (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
@@ -915,6 +944,7 @@ class KnowledgePack(VisualizeMixin):
         return self._feature_file_cache
 
     def initialize_from_dict(self, init_dict):
+        self._init_dict = init_dict
         self._uuid = init_dict["uuid"]
         self._name = init_dict["name"]
         self._configuration_index = init_dict["configuration_index"]
@@ -934,6 +964,7 @@ class KnowledgePack(VisualizeMixin):
             self._project_name = json.loads(init_dict["project_name"])
             self._sandbox_name = json.loads(init_dict["sandbox_name"])
             self._feature_file_uuid = json.loads(init_dict["feature_file_uuid"])
+            self._training_metrics = json.loads(init_dict("training_metrics"))
             self._knowledgepack_summary = json.loads(
                 init_dict.get("knowledgepack_summary", "")
             )
@@ -959,6 +990,7 @@ class KnowledgePack(VisualizeMixin):
             self._knowledgepack_description = init_dict.get(
                 "knowledgepack_description", None
             )
+            self._training_metrics = init_dict.get("training_metrics", None)
 
 
 def get_knowledgepack(kp_uuid, connection):
