@@ -50,8 +50,7 @@ class Query(object):
     """Base class for a query.
 
     Queries extract project data, or a subset of project data, for use in a pipeline. The query must specify which
-    columns of data to extract and what filter conditions to apply, and KnowledgeBuilder takes care of the database
-    joins required to produce a clean, analysis-ready data frame.
+    columns of data to extract and what filter conditions to apply.
     """
 
     def __init__(self, connection, project):
@@ -340,8 +339,24 @@ class Query(object):
 
         return response_data
 
+    def cache_queryv1(self, renderer=None):
+        """Caches the current version of the query."""
+        url = "project/{0}/query/{1}/cache-v1/".format(self._project.uuid, self.uuid)
+        request = self._connection.request("post", url)
+        response_data, err = utility.check_server_response(request, renderer=renderer)
+
+        return response_data
+
+    def cache_queryv2(self, renderer=None):
+        """Caches the current version of the query."""
+        url = "project/{0}/query/{1}/cache-v2/".format(self._project.uuid, self.uuid)
+        request = self._connection.request("post", url)
+        response_data, err = utility.check_server_response(request, renderer=renderer)
+
+        return response_data
+
     def cache_query_status(self, renderer=None):
-        """Gest the status of the current caching of the querey"""
+        """Gest the status of the current caching of the query"""
         url = "project/{0}/query/{1}/cache/".format(self._project.uuid, self.uuid)
         request = self._connection.request("get", url)
         response_data, err = utility.check_server_response(request, renderer=renderer)
@@ -380,6 +395,26 @@ class Query(object):
         else:
             return response
 
+    def check_query_cache_up_to_date(self, renderer=None):
+        """Checks if the current cached query is up to date with the current training data.
+
+        The sensor data in a query is cached when the query is built. If the segments or metadata
+        have changed since the last time the sensor data was cached then in order for a query to
+        use the new data it needs to be rebuilt. This API returns whether or not the sensor data
+        has changed since the last time the query was cached.
+
+        """
+
+        url = "project/{0}/query/{1}/cache-status/".format(
+            self._project.uuid, self.uuid
+        )
+        response = self._connection.request("get", url)
+        response_data, err = utility.check_server_response(response, renderer=renderer)
+        if err is False:
+            return response_data
+        else:
+            return response
+
     def plot_statistics(self, renderer=None, **kwargs):
         """Generates a bar plot of the query statistics"""
         data = self.statistics_segments(renderer=renderer)
