@@ -317,6 +317,8 @@ class Sandbox(object):
         self._device_config = DeviceConfig()
         self._created_at = None
         self._last_modified = None
+        self._last_cpu_clock_time = None
+        self._active = False
 
     @property
     def uuid(self):
@@ -343,6 +345,14 @@ class Sandbox(object):
     def cache(self):
         return self._cache_enabled
 
+    @property
+    def last_cpu_clock_time(self):
+        return self._last_cpu_clock_time
+
+    @property
+    def active(self):
+        return self._active
+
     @property
     def results(self):
         return self._results
@@ -426,6 +436,8 @@ class Sandbox(object):
                 self._init_device_config(response_data)
                 self._dirty = False
 
+            return response
+
     def delete(self):
         """Calls the REST API to delete the object from the server."""
         url = "project/{0}/sandbox/{1}/".format(self._project.uuid, self.uuid)
@@ -559,9 +571,10 @@ class Sandbox(object):
         data, err = utility.check_server_response(response)
         if err is False:
             response_data = data
-
             return response_data
 
+        return response
+
     def execute(self):
         """Executes the sandbox pipeline and returns results.
 
@@ -587,7 +600,7 @@ class Sandbox(object):
         if err is False:
             return response_data
 
-    def auto(self, auto_params, seed, renderer=None, version=1):
+    def auto(self, auto_params, renderer=None, version=1):
         """Submits the automation job for asynchronous execution and returns the task status."""
 
         if renderer is None:
@@ -685,7 +698,8 @@ class Sandbox(object):
         response_data, err = utility.check_server_response(response)
         if err is False:
             print(response_data)
-            return response_data
+
+        return response
 
     def submit(self):
         """Submits a pipeline for asynchronous execution."""
@@ -716,12 +730,16 @@ class Sandbox(object):
             self.name = data["name"]
             self.created_at = data.get("created_at", None)
             self.last_modified = data.get("last_modified", None)
+            self._last_cpu_clock_time = data.get("last_cpu_clock_time", None)
+            self._active = data.get("active", False)
             if not data.get("cache_enabled", True):
                 self.disable_cache()
             self._init_device_config(data)
             self.pipeline._steps = data["pipeline"]
             self._dirty = False
 
+        return response
+
     def delete_cache(self):
         """Calls the REST API and deletes the server cache for the sandbox."""
         if self._check_sandbox_inserted(insert=False):
@@ -730,6 +748,7 @@ class Sandbox(object):
             data, err = utility.check_server_response(response)
             if err is False:
                 print(data)
+            return response
 
     def initialize_from_dict(self, init_dict):
         """Populates a single sandbox from a dictionary of properties.
@@ -741,11 +760,13 @@ class Sandbox(object):
         self.name = init_dict["name"]
         self.created_at = init_dict.get("created_at", None)
         self.last_modified = init_dict.get("last_modified", None)
+        self._last_cpu_clock_time = init_dict.get("last_cpu_clock_time", None)
+        self._active = init_dict.get("active", None)
 
         if not init_dict.get("cache_enabled", True):
             self.disable_cache()
 
-        if len(init_dict["pipeline"]) != 0:
+        if init_dict["pipeline"] and len(init_dict["pipeline"]) != 0:
             self._pipeline._steps = init_dict["pipeline"]
         else:
             self._pipeline._steps = []
