@@ -9,6 +9,7 @@ from collections import OrderedDict
 from matplotlib.lines import Line2D
 import matplotlib.pyplot as plt
 from typing import List, Optional, Dict, Tuple
+import wave
 
 
 class DCLProject:
@@ -84,7 +85,15 @@ class DCLProject:
         df = pd.DataFrame(results, columns=header)
 
         if "uuid" in header:
-            df["uuid"] = df["uuid"].apply(lambda x: uuid.UUID(bytes=x) if x else None)
+            df["uuid"] = df["uuid"].apply(
+                lambda x: uuid.UUID(bytes_le=x) if x else None
+            )
+
+        if "last_modified" in header:
+            df["last_modified"] = pd.to_datetime(df["last_modified"])
+
+        if "created_at" in header:
+            df["created_at"] = pd.to_datetime(df["created_at"])
 
         if "local_status" in header:
             local_status = {
@@ -166,7 +175,32 @@ class DCLProject:
 
         return self._execute_query(query_select + query_join + query_where, header)
 
-    def list_captures(self) -> DataFrame:
+    def _list_captures_metadata(self) -> DataFrame:
+        "returns a dataframe containing the capture name and the associated metadata"
+
+        fields = ["uuid"]
+
+        fk_fields = OrderedDict(
+            [("Capture", "capture"), ("LabelValue", "label_value"), ("Label", "label")]
+        )
+
+        df = self._list_table("CaptureMetadataValue", fields, fk_fields=fk_fields)
+
+        M = []
+        for capture_name in df.capture.unique():
+            caps_dict = df[df.capture == capture_name][
+                ["label", "label_value"]
+            ].to_dict(orient="records")
+            tmp = {"capture": capture_name}
+            for item in caps_dict:
+                tmp[item["label"]] = item["label_value"]
+            M.append(tmp)
+
+        return DataFrame(M).fillna("")
+
+    def list_captures(self, include_metadata: bool = True) -> DataFrame:
+        "returns a dataframe containing the capture information. If inlcude_metadta is True, also returns the associated metadata information with each capture."
+
         fields = [
             "uuid",
             "name",
@@ -180,7 +214,14 @@ class DCLProject:
 
         fk_fields = OrderedDict([("CaptureConfiguration", "capture_configuration")])
 
-        return self._list_table("Capture", fields=fields, fk_fields=fk_fields)
+        df = self._list_table("Capture", fields=fields, fk_fields=fk_fields)
+
+        if not include_metadata:
+            return df
+
+        return df.merge(
+            self._list_captures_metadata(), left_on="name", right_on="capture"
+        ).drop("capture", axis=1)
 
     def list_sessions(self) -> DataFrame:
         fields = [
@@ -199,20 +240,30 @@ class DCLProject:
         return self._list_table("Segmenter", fields, fk_fields)
 
     def list_capture_segments(
-        self, capture: Optional[str] = None, session: Optional[str] = None
+        self, captures: Optional[List] = None, sessions: Optional[List] = None
     ) -> DataFrame:
 
+        if captures is not None and isinstance(captures, str):
+            captures = [captures]
+        if sessions is not None and isinstance(sessions, str):
+            sessions = [sessions]
+
         query_filter = ""
 
-        if capture and session:
-            query_filter = 'WHERE Capture.name="{}" '.format(
-                capture
-            ) + 'AND Segmenter.name = "{0}" '.format(session)
+        def create_select(select):
+            return ", ".join(['"{}"'.format(x) for x in select])
 
-        elif capture:
-            query_filter = 'WHERE Capture.name="{}" '.format(capture)
-        elif session:
-            query_filter += 'WHERE Segmenter.name = "{0}" '.format(session)
+        if captures and sessions:
+            query_filter = "WHERE Capture.name in ({}) ".format(
+                create_select(captures)
+            ) + "AND Segmenter.name in ({0}) ".format(create_select(sessions))
+
+        elif captures:
+            query_filter = "WHERE Capture.name in ({}) ".format(create_select(captures))
+        elif sessions:
+            query_filter += "WHERE Segmenter.name in ({0}) ".format(
+                create_select(sessions)
+            )
 
         fields = [
             "uuid",
@@ -231,7 +282,9 @@ class DCLProject:
             ]
         )
 
-        return self._list_table("CaptureLabelValue", fields, fk_fields, query_filter)
+        return self._list_table(
+            "CaptureLabelValue", fields, fk_fields, query_filter
+        ).sort_values(by=["capture", "segmenter", "capture_sample_sequence_start"])
 
     def get_capture_metadata(self, capture: str) -> DataFrame:
         "returns a dataframe containing the metadata associated with this capture"
@@ -246,7 +299,9 @@ class DCLProject:
 
         return df[df["capture"] == capture]
 
-    def get_capture_segments(self, capture: str, session: str):
+    def get_capture_segments(
+        self, captures: Optional[List] = None, sessions: Optional[List] = None
+    ):
         """
         Returns a DataSegment object of the specified capture and session
 
@@ -259,16 +314,17 @@ class DCLProject:
             groups (dict): a dict of key value pairs where the key is the original label the value is the label it was should be renamed to
 
         """
+        if captures is not None and isinstance(captures, str):
+            captures = [captures]
+        if sessions is not None and isinstance(sessions, str):
+            sessions = [sessions]
 
-        labels = self.list_capture_segments(
-            capture=capture, session=session
-        ).sort_values(by="capture_sample_sequence_start")
-
-        # TODO: read wave file if file is .wav
-        tmp_df = pd.read_csv(os.path.join(self.data_dir, capture), index_col="sequence")
+        labels = self.list_capture_segments(captures=captures, sessions=sessions)
 
         M = DataSegments()
 
+        cached_df = None
+        capture_index = 4
         for index, label in enumerate(
             labels[
                 [
@@ -277,12 +333,19 @@ class DCLProject:
                     "uuid",
                     "label_value",
                     "capture",
+                    "segmenter",
                 ]
             ].values
         ):
+            # TODO: read wave file if file is .wav#
+            if cached_df != label[capture_index]:
+                tmp_df = self.get_capture(label[capture_index])
+                cached_df = label[capture_index]
+
             M[index] = DataSegment(
                 tmp_df.loc[label[0] : label[1]],
-                segment_index=index,
+                segment_id=index,
+                session=label[5],
                 label=label[3],
                 uuid=label[2],
                 capture=label[4],
@@ -300,29 +363,44 @@ class DCLProject:
         """
 
         # TODO: read wave file if file is .wav
-        tmp_df = pd.read_csv(
-            os.path.join(self.data_dir, capture_name), index_col="sequence"
-        )
+        ext = capture_name.split(".")[-1]
+
+        if ext == "csv":
+            tmp_df = pd.read_csv(
+                os.path.join(self.data_dir, capture_name), index_col="sequence"
+            )
+        elif ext == "wav":
+            with wave.open(
+                os.path.join(self.data_dir, capture_name), "rb"
+            ) as wave_reader:
+                waveFrames = wave_reader.readframes(wave_reader.getnframes())
+                waveData = np.fromstring(waveFrames, dtype=np.int16).reshape(
+                    (-1, wave_reader.getnchannels())
+                )
+                columns = [
+                    "channel_{}".format(i) for i in range(wave_reader.getnchannels())
+                ]
+                tmp_df = DataFrame(waveData, columns=columns).rename_axis(
+                    index="sequence"
+                )
 
         return tmp_df
 
     def get_captures(self, capture_names: Optional[List[str]] = None) -> DataFrame:
         """
-        Returns the capture as a single dataframe
+        Returns the capture as a list of dataframes
 
         Args:
             capture_names (List[str]): name of captures to return, if None returns all captures
 
         """
         if capture_names is None:
-            capture_names = os.listdir(self.datadir)
+            capture_names = os.listdir(self.data_dir)
 
-        return pd.concat(
-            map(
-                pd.read_csv,
-                [os.path.join(self.datadir, capture) for capture in capture_names],
-            )
-        ).reset_index(drop=True)
+        return {
+            capture_name: self.get_capture(capture_name)
+            for capture_name in capture_names
+        }
 
     def plot_segment_labels(
         self,
@@ -395,7 +473,10 @@ class DCLProject:
             capture_names = [capture_names]
 
         for capture_name in capture_names:
-            segments = self.list_capture_segments(capture_name, session)
+
+            segments = self.list_capture_segments(
+                captures=[capture_name], sessions=[session]
+            )
             capture = self.get_capture(capture_name)
             M.append(capture)
 
