@@ -117,7 +117,7 @@ class Pipeline(object):
         Results of automl stats for each iteration
 
         Returns:
-            DataFrame: Automl resutls stats
+            DataFrame: AutoML results stats
         """
 
         url = "project/{0}/sandbox/{1}/automl-iteration-metrics/".format(
@@ -258,7 +258,7 @@ class Pipeline(object):
             try:
                 if kp_summary:
                     if not knowledgepack.knowledgepack_summary:
-                        print("Knowledpack doesn't have a summary.")
+                        print("Knowledge Pack doesn't have a summary.")
                         return
                     steps = (
                         [knowledgepack.pipeline_summary[0]]
@@ -422,7 +422,7 @@ class Pipeline(object):
 
                 - survivor_rate, (float, 0.5): Ratio of the population that will be transferred to next generation.
 
-                - number_of_models_to_return, (int, 5): Number of pipeline that will return to user.
+                - number_of_models_to_return, (int, 5): Number of pipelines that will return to user.
 
                 - allow_unknown, (bool, False): Allows creating unknown prediction results for the vectors. A vector is classified as an unknown if it
 
@@ -509,9 +509,8 @@ class Pipeline(object):
         if self._label_column:
             auto_params["label_column"] = self._label_column
 
-        seed = self._kb.seeds.get_seed_by_name(auto_params["seed"])
         success = self._sandbox.auto(
-            auto_params=auto_params, seed=seed, renderer=renderer, version=version
+            auto_params=auto_params, renderer=renderer, version=version
         )
         if success:
             return self.get_results(lock=lock, silent=silent, renderer=renderer)
@@ -519,7 +518,7 @@ class Pipeline(object):
 
     def grid_search(self, grid_params, run_parallel=True, lock=True, silent=True):
         """
-        Grid search is a parameter optimization method that exhaustivley searches over a gridded parameter space.
+        Grid search is a parameter optimization method that exhaustively searches over a gridded parameter space.
         Grid search returns will return the score each parameter combination for f1, precision and sensitivity so that
         you can choose the best performing combination to build a knowledge pack with.
 
@@ -668,7 +667,7 @@ class Pipeline(object):
         """Makes a plot of feature vectors by class to aid in understanding your model
 
         Args:
-            model (model/knowledpack): The model or knowledpack to use for plotting the neurons
+            model (model/knowledgepack): The model or knowledgepack to use for plotting the neurons
             feature_vector (DataFrame): Dataframe containing feature vectors and label column
             featureX (str): The name of the feature for the x axis
             featureY (str): The name of the feature for the y axis
@@ -1035,6 +1034,7 @@ class Pipeline(object):
             name (str): Name of the training algorithm.
             params (dict, optional): Parameters of the training algorithm.
         """
+
         self._training_algorithm_call = (
             call
         ) = self._kb.functions.create_training_algorithm_call(name)
@@ -1327,7 +1327,6 @@ class Pipeline(object):
         class_map=None,
         dtype=int,
     ):
-
         if label is None:
             label = self._label_column
 
@@ -1371,14 +1370,14 @@ class Pipeline(object):
         )
 
         print("-----  Summary  -----")
-        print("Class Map:", class_map)
+        print("Class Map:" + str(class_map))
         print("Train:\n total: ", x_train.shape[0])
         print(" by class:", y_train.sum(axis=0))
 
         print("Validate:\n total: ", x_validate.shape[0])
         print(" by class:", y_validate.sum(axis=0))
 
-        print("Train:\n total: ", x_test.shape[0])
+        print("Test:\n total: ", x_test.shape[0])
         print(" by class:", y_test.sum(axis=0))
 
         return (
